The Phase Dispersion Minimization (PDM) analysis
=================================================

The PDM analysis is described by Stellingwerf 1978 [#St78]_. It is
a tool to find (eventually nonsinusodial) periodic variation
in time series data by minimizing the dispersion of the
folded data set. The dispersion is obtained bin-wise.


.. toctree::
   :maxdepth: 2
   
   classes.rst
   examples.rst


.. [#St78] Stellingwerf 1978, "Period determination using phase dispersion minimization", 1978ApJ...224..953S
